tlslite.utils.pycrypto_rsakey.PyCrypto_RSAKey

Package tlslite :: Package utils :: Module pycrypto_rsakey :: Class PyCrypto_RSAKey |
[hide private]
[frames] | no frames]

# Class PyCrypto_RSAKey

source code

    rsakey.RSAKey --+
                    |
                   PyCrypto_RSAKey

Instance Methods | [hide private]
__getattr__(self, name) | source code
__init__(self, n=0, e=0, d=0, p=0, q=0, dP=0, dQ=0, qInv=0) Create a new RSA key. | source code
_rawPrivateKeyOp(self, m) | source code
_rawPublicKeyOp(self, c) | source code
bool |
hasPrivateKey(self) Return whether or not this key has a private component. | source code
Inherited from `rsakey.RSAKey`: `__len__`, `acceptsPassword`, `decrypt`, `encrypt`, `hashAndSign`, `hashAndVerify`, `sign`, `verify`, `write` Inherited from `rsakey.RSAKey` (private): `_addPKCS1Padding`, `_addPKCS1SHA1Prefix`

Static Methods | [hide private]
tlslite.utils.RSAKey.RSAKey |
generate(bits) Generate a new key with the specified bit length. | source code

Method Details | [hide private]

### __init__(self, n=0, e=0, d=0, p=0, q=0, dP=0, dQ=0, qInv=0) (Constructor) | source code
Create a new RSA key. If n and e are passed in, the new key will be initialized. Parameters: `n` - RSA modulus. `e` - RSA public exponent. Overrides: rsakey.RSAKey.__init__ (inherited documentation)

### _rawPrivateKeyOp(self, m) | source code
Overrides: rsakey.RSAKey._rawPrivateKeyOp

### _rawPublicKeyOp(self, c) | source code
Overrides: rsakey.RSAKey._rawPublicKeyOp

### generate(bits) Static Method | source code
Generate a new key with the specified bit length. Returns: tlslite.utils.RSAKey.RSAKey Overrides: rsakey.RSAKey.generate (inherited documentation)

### hasPrivateKey(self) | source code
Return whether or not this key has a private component. Returns: bool Overrides: rsakey.RSAKey.hasPrivateKey (inherited documentation)